========
Overview
========

This plugin enables control over the access of remote data when running
pytests. It has been moved from the core astropy project since it is of use
more generally. It is currently WIP.
